'use strict';

var _electron = require('electron');

var _yargs = require('yargs');

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _universalAnalytics = require('universal-analytics');

var _universalAnalytics2 = _interopRequireDefault(_universalAnalytics);

var _uuid = require('uuid');

var _uuid2 = _interopRequireDefault(_uuid);

var _winston = require('winston');

var _winston2 = _interopRequireDefault(_winston);

var _configureApp = require('./main/configureApp');

var _configureApp2 = _interopRequireDefault(_configureApp);

var _configureBrowser = require('./main/configureBrowser');

var _configureBrowser2 = _interopRequireDefault(_configureBrowser);

var _Emitter = require('./main/utils/Emitter');

var _Emitter2 = _interopRequireDefault(_Emitter);

var _Settings = require('./main/utils/Settings');

var _Settings2 = _interopRequireDefault(_Settings);

var _WindowManager = require('./main/utils/WindowManager');

var _WindowManager2 = _interopRequireDefault(_WindowManager);

var _PlaybackAPI = require('./main/utils/PlaybackAPI');

var _PlaybackAPI2 = _interopRequireDefault(_PlaybackAPI);

var _I3IpcHelper = require('./main/utils/I3IpcHelper');

var _I3IpcHelper2 = _interopRequireDefault(_I3IpcHelper);

var _squirrel = require('./squirrel');

var _squirrel2 = _interopRequireDefault(_squirrel);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

(function () {
  if ((0, _squirrel2.default)()) {
    return;
  }

  global.DEV_MODE = _yargs.argv.development || _yargs.argv.dev;

  // Initialize the logger with some default logging levels.
  var defaultFileLogLevel = 'info';
  var defaultConsoleLogLevel = global.DEV_MODE ? 'debug' : 'error';
  global.Logger = new _winston2.default.Logger({
    transports: [new _winston2.default.transports.File({
      filename: _path2.default.resolve(_electron.app.getPath('userData'), 'gpmdc.log'),
      level: defaultFileLogLevel,
      maxsize: 5000000,
      maxfiles: 2
    }), new _winston2.default.transports.Console({
      level: defaultConsoleLogLevel
    })]
  });

  Logger.info('Application started.');

  (0, _configureApp2.default)(_electron.app);

  // Keep a global reference of the window object, if you don't, the window will
  // be closed automatically when the JavaScript object is garbage collected.
  var mainWindow = null;

  // DEV: Make the app single instance
  var shouldQuit = _electron.app.makeSingleInstance(function () {
    if (mainWindow) {
      if (mainWindow.isMinimized()) mainWindow.restore();
      mainWindow.focus();
      mainWindow.show();
      mainWindow.setSkipTaskbar(false);
      if (_electron.app.dock && _electron.app.dock.show) _electron.app.dock.show();
    }
  });

  if (shouldQuit) {
    _electron.app.quit();
    return;
  }

  global.Emitter = new _Emitter2.default();
  global.WindowManager = new _WindowManager2.default();
  global.Settings = new _Settings2.default();
  global.PlaybackAPI = new _PlaybackAPI2.default();

  // UA for GA
  // This is for user reporting
  Settings.set('uuid', Settings.get('uuid', _uuid2.default.v4()));
  var user = (0, _universalAnalytics2.default)('UA-44220619-5', Settings.get('uuid'));
  setInterval(function sendPageView() {
    user.pageview('/').send();
    return sendPageView;
  }(), 60000 * 5);

  // Replace the logger's levels with those from settings.
  Logger.transports.console.level = Settings.get('consoleLogLevel', defaultConsoleLogLevel);
  Logger.transports.file.level = Settings.get('fileLogLevel', defaultFileLogLevel);

  // Quit when all windows are closed.
  _electron.app.on('window-all-closed', function () {
    // On OS X it is common for applications and their menu bar
    // to stay active until the user quits explicitly with Cmd + Q
    if (process.platform !== 'darwin') {
      _electron.app.quit();
    }
  });

  // This method will be called when Electron has finished
  // initialization and is ready to create browser windows.
  _electron.app.on('ready', function () {
    var _mainWindow;

    mainWindow = new _electron.BrowserWindow((0, _configureBrowser2.default)());
    global.mainWindowID = WindowManager.add(mainWindow, 'main');

    var position = Settings.get('position');
    var inBounds = false;
    if (position) {
      _electron.screen.getAllDisplays().forEach(function (display) {
        if (position[0] >= display.workArea.x && position[0] <= display.workArea.x + display.workArea.width && position[1] >= display.workArea.y && position[1] <= display.workArea.y + display.workArea.height) {
          inBounds = true;
        }
      });
    }

    var size = Settings.get('size');
    size = size || [1200, 800];

    (_mainWindow = mainWindow).setSize.apply(_mainWindow, _toConsumableArray(size));
    if (position && inBounds) {
      var _mainWindow2;

      (_mainWindow2 = mainWindow).setPosition.apply(_mainWindow2, _toConsumableArray(position));
    } else {
      mainWindow.center();
    }

    if (Settings.get('maximized', false)) {
      mainWindow.maximize();
    }

    // and load the index.html of the app.
    mainWindow.loadURL('file://' + __dirname + '/public_html/index.html');
    require('./main/features');
    require('./old_win32');

    // Emitted when the window is closed.
    mainWindow.on('closed', function () {
      // Dereference the window object, usually you would store windows
      // in an array if your app supports multi windows, this is the time
      // when you should delete the corresponding element.
      mainWindow = null;
      PlaybackAPI.reset();
    });

    // setup i3 listener
    var I3IpcHelper = new _I3IpcHelper2.default();
    I3IpcHelper.setupEventListener();
  });

  _electron.app.on('before-quit', function () {
    Logger.info('Application exiting...');
    global.quiting = true;
  });
})();