'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var COMMAND_CONNECTORS = ['and then', 'and', 'then'];

var SpeechRecognizer = function () {
  function SpeechRecognizer() {
    var _this = this;

    var hotwords = arguments.length <= 0 || arguments[0] === undefined ? [] : arguments[0];
    var prefixes = arguments.length <= 1 || arguments[1] === undefined ? [] : arguments[1];

    _classCallCheck(this, SpeechRecognizer);

    this.hotwords = hotwords;
    this.prefixes = prefixes;
    this.enabled = false;
    this.speech = new window.webkitSpeechRecognition(); // eslint-disable-line

    this.speech.onresult = this._onSpeech.bind(this);

    this.speech.onerror = function () {
      return _this.speech.stop();
    };
    this.speech.onnomatch = function () {
      return _this.speech.stop();
    };
    this.speech.onend = function () {
      if (_this.enabled) {
        _this.speech.start();
      }
    };

    this._handlers = {};
  }

  _createClass(SpeechRecognizer, [{
    key: 'enable',
    value: function enable() {
      this.speech.stop();
      this.speech.start();
      this.enabled = true;
    }
  }, {
    key: 'disable',
    value: function disable() {
      this.enabled = false;
      this.speech.stop();
    }
  }, {
    key: '_onSpeech',
    value: function _onSpeech(event) {
      var _this2 = this;

      var results = event.results;
      if (results['0'] && results['0']['0']) {
        (function () {
          var said = results['0']['0'].transcript.trim();
          _lodash2.default.forEach(_this2.hotwords, function (hotword) {
            if (said.substr(0, hotword.length) === hotword) {
              _this2.handleCommand(said.substr(hotword.length).trim());
              return false;
            }
          });
        })();
      }
      this.speech.stop();
    }
  }, {
    key: 'handleCommand',
    value: function handleCommand(command) {
      var _this3 = this;

      if (!command) return;
      var matchedFn = void 0;
      var matchedKey = '';
      var fnArg = void 0;

      _lodash2.default.forIn(this._handlers, function (fn, key) {
        if (command.substr(0, key.length).toLowerCase() === key) {
          if (key.length > matchedKey.length) {
            matchedKey = key;
            matchedFn = fn;
            fnArg = command.substr(key.length).trim();
          }
        }
      });

      if (matchedFn) {
        matchedFn(fnArg).catch(function (error) {
          Logger.info(error);
        }).then(function (unusedCommand) {
          if (unusedCommand === undefined) {
            unusedCommand = fnArg; // eslint-disable-line
          }
          var handled = false;
          _lodash2.default.forEach(COMMAND_CONNECTORS, function (connector) {
            if (unusedCommand.substr(0, connector.length) === connector) {
              handled = true;
              _this3.handleCommand(unusedCommand.substr(connector.length).trim());
              return false;
            }
          });
          if (!handled) {
            _this3.handleCommand(unusedCommand.trim());
          }
        });
      } else {
        Logger.warn('Command: "' + command + '" did not match any registered handlers');
      }
    }
  }, {
    key: 'registerHandler',
    value: function registerHandler(action, fn) {
      var _this4 = this;

      var actions = action;
      if (!_lodash2.default.isArray(actions)) actions = [action];

      _lodash2.default.forEach(actions, function (actionString) {
        if (_this4._handlers[actionString.toLowerCase()]) {
          Logger.error('The action "' + action.toLowerCase() + '" already has a handler registered'); // eslint-disable-line
        } else {
            _lodash2.default.forEach(_this4.prefixes.concat(['']), function (prefix) {
              _this4._handlers[(prefix.toLowerCase() + ' ' + actionString.toLowerCase()).trim()] = fn;
            });
          }
      });
    }
  }]);

  return SpeechRecognizer;
}();

exports.default = SpeechRecognizer;