'use strict';

var _SpeechRecognizer = require('./SpeechRecognizer');

var _SpeechRecognizer2 = _interopRequireDefault(_SpeechRecognizer);

var _playPlaylist = require('./utils/playPlaylist');

var _playPlaylist2 = _interopRequireDefault(_playPlaylist);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

window.wait(function () {
  var speech = new _SpeechRecognizer2.default(['ok player', 'okayplayer', 'hey music', 'yo music'], // Hot Words
  ['Let\'s', 'can you', 'can you please', 'please'] // Command prefix
  );

  Emitter.on('speech:toggle', function (event, details) {
    if (details.state) {
      speech.enable();
    } else {
      speech.disable();
    }
  });
  if (Settings.get('speechRecognition', false)) speech.enable();

  // Play Playlist Handlers
  speech.registerHandler(['play playlist', 'play the playlist'], _playPlaylist2.default);

  // Play / Pause Handlers
  var playing = false;
  GPM.on('change:playback', function (mode) {
    playing = mode === 2;
  });
  speech.registerHandler(['pause', 'pours', 'paws', 'Paul\'s'], function () {
    return new Promise(function (resolve) {
      if (playing) GPM.playback.playPause();
      resolve();
    });
  });
  speech.registerHandler('play', function () {
    return new Promise(function (resolve) {
      if (!playing) GPM.playback.playPause();
      resolve();
    });
  });

  // Track Navigation Handlers
  speech.registerHandler(['next', 'next track', 'forward', 'fast forward'], function () {
    return new Promise(function (resolve) {
      GPM.playback.forward();
      resolve();
    });
  });

  speech.registerHandler(['back', 'previous', 'rewind', 'start again'], function () {
    return new Promise(function (resolve) {
      GPM.playback.rewind();
      resolve();
    });
  });

  speech.registerHandler(['this song sucks', 'the song sucks'], function () {
    return new Promise(function (resolve) {
      GPM.rating.setRating(1);
      resolve();
    });
  });

  speech.registerHandler(['this song is great', 'this song rules', 'this song is epic', 'this song is awesome', 'this song rocks', 'the song is great', 'the song rules', 'the song is epic', 'the song is awesome', 'the song rocks'], function () {
    return new Promise(function (resolve) {
      GPM.rating.setRating(5);
      resolve();
    });
  });

  // Shuffle Handlers
  speech.registerHandler(['mixitup', 'mix it up', 'shuffle', 'shake', 'random'], function () {
    return new Promise(function (resolve) {
      if (GPM.playback.getShuffle() === window.GMusic.Playback.ALL_SHUFFLE) {
        GPM.playback.toggleShuffle();
      }
      GPM.playback.toggleShuffle();
      GPM.playback.forward();
      resolve();
    });
  });

  speech.registerHandler(['turn shuffle on', 'shuffle on'], function () {
    return new Promise(function (resolve) {
      if (GPM.playback.getShuffle() === window.GMusic.Playback.NO_SHUFFLE) {
        GPM.playback.toggleShuffle();
      }
      resolve();
    });
  });

  speech.registerHandler(['turn shuffle off', 'shuffle off'], function () {
    return new Promise(function (resolve) {
      if (GPM.playback.getShuffle() === window.GMusic.Playback.ALL_SHUFFLE) {
        GPM.playback.toggleShuffle();
      }
      resolve();
    });
  });

  // Album Navigation Handlers
  speech.registerHandler(['goto artist', 'go to artist', 'load artist', 'navigate to artist'], function (artistName) {
    return new Promise(function (resolve) {
      if (!artistName) {
        resolve();return;
      }
      window.location = '/music/listen#/artist//' + artistName;
      resolve('');
    });
  });

  // Desktop Settings Trigger
  speech.registerHandler(['settings', 'open settings', 'show settings', 'load settings'], function () {
    return new Promise(function (resolve) {
      Emitter.fire('window:settings');
      resolve();
    });
  });

  // Volume Controls
  speech.registerHandler(['turn it up', 'bring it up', 'turn the volume up', 'make it louder', 'i can\'t here it', 'i can\'t hear it'], function () {
    return new Promise(function (resolve) {
      GPM.volume.increaseVolume();
      resolve();
    });
  });

  speech.registerHandler(['turn it down', 'take it down', 'turn the volume down', 'make it quieter', 'make it more quiet'], function () {
    return new Promise(function (resolve) {
      GPM.volume.decreaseVolume();
      resolve();
    });
  });

  speech.registerHandler(['set volume to', 'set the volume to', 'make the volume', 'set the volume 2', 'set volume 2', 'set volume'], function (num) {
    return new Promise(function (resolve) {
      var targetVol = parseInt(num, 10);
      if (targetVol) {
        GPM.volume.setVolume(Math.min(Math.max(0, targetVol), 100));
      }
      resolve(num.replace(new RegExp(targetVol.toString() + '%', 'g'), '').trim());
    });
  });

  var origVolume = void 0;
  speech.registerHandler(['make it boom', 'make it burn', 'sing it out', 'pump it', 'get this party started'], function () {
    return new Promise(function (resolve) {
      origVolume = origVolume || GPM.volume.getVolume();
      GPM.volume.setVolume(100);
      resolve();
    });
  });

  speech.registerHandler(['shut up', 'mute', 'silence', 'turn this right down', 'party is over', 'party\'s over'], function () {
    return new Promise(function (resolve) {
      origVolume = origVolume || GPM.volume.getVolume();
      GPM.volume.setVolume(0);
      resolve();
    });
  });

  speech.registerHandler(['reset the volume', 'normalize', 'normalise'], function () {
    return new Promise(function (resolve) {
      GPM.volume.setVolume(origVolume);
      origVolume = null;
      resolve();
    });
  });
});