'use strict';

var _electron = require('electron');

window.addEventListener('load', function () {
  if (!window.$) return;
  if (!$('#lyrics').length) return;
  var animate = false;
  var animationTimer = void 0;
  var noLyricsTimer = void 0;
  var jumpDetect = void 0;

  _electron.remote.getGlobal('PlaybackAPI').on('change:lyrics', function (lyrics) {
    if (!lyrics) {
      $('#lyrics').html('<h1>Loading lyrics...</h1>');
      $('#lyrics p').stop();
      animate = false;
      noLyricsTimer = setTimeout(function () {
        $('#lyrics').html('<h1>Sorry, we could not find any lyrics for this song</h1>');
      }, 4000);
    } else {
      clearTimeout(noLyricsTimer);
      var lyricsHTML = lyrics.replace(/\n/g, '<br />');
      $('#lyrics').html('<p>' + lyricsHTML + '</p>');
      animate = true;
    }
  });

  _electron.remote.getGlobal('PlaybackAPI').on('change:state', function (isPlaying) {
    if (!isPlaying) return $('#lyrics p').stop() && setTimeout(function () {
      return animate = true;
    }, 10);
  });

  _electron.remote.getGlobal('PlaybackAPI').on('change:time', function (timeObj) {
    var jumped = false;
    if (timeObj.current < jumpDetect || timeObj.current - jumpDetect > 1000) {
      animate = true;
      jumped = true;
    }
    if (!animate || !timeObj.total || !$('#lyrics p').get(0)) return;
    var lyricsP = $('#lyrics p');
    var maxHeight = parseInt(lyricsP.get(0).scrollHeight, 10);
    var viewPortHeight = parseInt(lyricsP.innerHeight(), 10);
    var waitTime = viewPortHeight / maxHeight * timeObj.total * 0.3;
    var actualWaitTime = Math.max(0, waitTime - timeObj.current);
    clearTimeout(animationTimer);
    if (jumped) {
      lyricsP.scrollTop(maxHeight * (Math.max(0, timeObj.current - waitTime) / timeObj.total));
    }
    animationTimer = setTimeout(function () {
      lyricsP.stop().animate({
        scrollTop: maxHeight - viewPortHeight
      }, timeObj.total - timeObj.current - actualWaitTime - waitTime, 'linear');
    }, actualWaitTime);
    animate = false;
  });

  window.addEventListener('resize', function () {
    animate = true;
  });
  $('#lyrics_back').click(function () {
    return $('#lyrics_back').removeClass('vis');
  });
});

Emitter.on('lyrics:show', function () {
  return $('#lyrics_back').addClass('vis');
});