'use strict';

var _electron = require('electron');

var _https = require('https');

var _https2 = _interopRequireDefault(_https);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var platform = 'win';
if (process.platform === 'darwin') {
  platform = 'osx';
}

var setUpAutoUpdate = function setUpAutoUpdate() {
  if (global.DEV_MODE) return;
  try {
    (function () {
      _electron.autoUpdater.setFeedURL('https://update.gpmdp.xyz/update/' + platform + '/' + _electron.app.getVersion());

      _electron.autoUpdater.on('error', function (error) {
        // Ignore it, errors happen
        Logger.debug('Auto updater error.', error);
      });

      _electron.autoUpdater.on('checking-for-update', function () {
        // Do something
        Logger.debug('Auto updater - checking for update...');
      });

      _electron.autoUpdater.on('update-available', function () {
        // Do something
        Logger.info('Auto updater - update available.');
      });

      _electron.autoUpdater.on('update-not-available', function () {
        Logger.debug('Auto updater - update not available.');
        setTimeout(function () {
          _electron.autoUpdater.checkForUpdates();
        }, 300000);
      });

      var update = false;
      _electron.autoUpdater.on('update-downloaded', function () {
        Logger.info('Auto updater - update downloaded.');
        Emitter.sendToAll('update:available');
        update = true;
      });

      Emitter.on('update:trigger', function () {
        Logger.info('Auto updater - update triggered.');
        if (update) {
          Logger.info('Auto updater - quitting to install.');
          global.quiting = true;
          _electron.autoUpdater.quitAndInstall();
        }
      });

      Emitter.on('update:wait', function () {
        setTimeout(function () {
          Emitter.sendToAll('update:available');
        }, 1200000);
      });

      _electron.autoUpdater.checkForUpdates();
    })();
  } catch (e) {
    Logger.error('Failed to setup auto update.', e);
  }
};

var checkUpdateServer = function checkUpdateServer() {
  _https2.default.get('https://update.gpmdp.xyz', function () {
    setUpAutoUpdate();
  }).on('error', function () {
    Logger.error('################### !! Update server down !! ##################');
    setTimeout(checkUpdateServer, 120000);
  });
};

checkUpdateServer();