'use strict';

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _electron = require('electron');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// ↓ Without the lambda it crashes - Electron bug ?
var keyRegisterFn = function keyRegisterFn() {
  return _electron.globalShortcut.register.apply(_electron.globalShortcut, arguments);
};
if (process.platform === 'win32') {
  (function () {
    var hook = require('ll-keyboard-hook-win');
    keyRegisterFn = function keyRegisterFn(key, fn) {
      hook.on('down', key, fn);
    };
  })();
}

keyRegisterFn('MediaPreviousTrack', function () {
  Emitter.sendToGooglePlayMusic('playback:previousTrack');
});

keyRegisterFn('MediaPlayPause', function () {
  Emitter.sendToGooglePlayMusic('playback:playPause');
});

keyRegisterFn('MediaNextTrack', function () {
  Emitter.sendToGooglePlayMusic('playback:nextTrack');
});

keyRegisterFn('MediaStop', function () {
  Emitter.sendToGooglePlayMusic('playback:stop');
});

var customHotkeysTemplate = {
  playPause: null,
  stop: null,
  previousTrack: null,
  nextTrack: null,
  thumbsUp: null,
  thumbsDown: null,
  increaseVolume: null,
  decreaseVolume: null
};

var userHotkeys = Settings.get('hotkeys', {});

var customHotkeys = _lodash2.default.extend(customHotkeysTemplate, userHotkeys);

var _unregisterHotkey = function _unregisterHotkey(accelerator) {
  try {
    if (accelerator && _electron.globalShortcut.isRegistered(accelerator)) {
      _electron.globalShortcut.unregister(accelerator);
    }
  } catch (e) {
    Logger.error('Exception unregistering hotkey.', { accelerator: accelerator, e: e });
  }
};

var _registerHotkeyIfSet = function _registerHotkeyIfSet(accelerator, action) {
  if (accelerator) {
    try {
      var success = _electron.globalShortcut.register(accelerator, function () {
        Emitter.sendToGooglePlayMusic('playback:' + action);
      });
      if (!success) {
        Logger.error('Failed to register hotkey.', { accelerator: accelerator, action: action });
      }
    } catch (e) {
      Logger.error('Exception registering hotkey.', { accelerator: accelerator, action: action, e: e });
    }
  }
};

_lodash2.default.forIn(customHotkeys, _registerHotkeyIfSet);

Emitter.on('hotkey:set', function (event, details) {
  var key = details.action;

  if (customHotkeys[key] || customHotkeys[key] === null) {
    _unregisterHotkey(customHotkeys[key]);
    customHotkeys[key] = details.accelerator;
    _registerHotkeyIfSet(customHotkeys[key], key);
    Settings.set('hotkeys', customHotkeys);
  }
});