'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.updateScrobble = exports.updateNowPlaying = exports.getLastFMSession = undefined;

var _electron = require('electron');

var _lastfm = require('lastfm');

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _constants = require('../../constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var lastfm = new _lastfm.LastFmNode({
  api_key: _constants.LASTFM_API_KEY,
  secret: _constants.LASTFM_API_SECRET,
  useragent: 'GPMDP'
});

var getLastFMToken = function getLastFMToken() {
  return new Promise(function (resolve, reject) {
    lastfm.request('auth.getToken').on('success', function (json) {
      resolve(json.token);
    }).on('error', function () {
      reject();
    });
  });
};

var authLastFMToken = function authLastFMToken(token) {
  return new Promise(function (resolve, reject) {
    var authWindow = new _electron.BrowserWindow({
      width: 1280,
      height: 720,
      center: true,
      show: false,
      autoHideMenuBar: true,
      frame: Settings.get('nativeFrame'),
      icon: _path2.default.resolve(__dirname + '/../../../assets/img/main.' + (process.platform === 'win32' ? 'ico' : 'png')), // eslint-disable-line
      title: 'Last.FM',
      webPreferences: {
        nodeIntegration: false,
        preload: _path2.default.resolve(__dirname + '/../../../inject/lastFM.js')
      }
    });
    authWindow.setMenu(null);
    authWindow.loadURL('http://www.last.fm/api/auth/?api_key=' + _constants.LASTFM_API_KEY + '&token=' + token);
    Emitter.once('lastfm:auth_result', function (event, accepted) {
      if (accepted.result) {
        resolve(token);
      } else {
        reject();
      }
    });
  });
};

var getLastFMSession = exports.getLastFMSession = function getLastFMSession() {
  return new Promise(function (resolve, reject) {
    if (global.lastFMSession && Settings.get('lastFMKey')) {
      resolve(global.lastFMSession);
    } else if (Settings.get('lastFMKey')) {
      global.lastFMSession = lastfm.session({
        key: Settings.get('lastFMKey'),
        user: Settings.get('lastFMUser')
      });
      resolve(global.lastFMSession);
    } else {
      getLastFMToken().then(function (token) {
        return authLastFMToken(token);
      }).then(function (token) {
        lastfm.session({
          token: token
        }).on('success', function (session) {
          global.lastFMSession = session;
          Settings.set('lastFMKey', session.key);
          Settings.set('lastFMUser', session.user);
          resolve(session);
        }).on('error', reject);
      }).catch(reject);
    }
  });
};

var resetLastFM = function resetLastFM() {
  Settings.set('lastFMKey', null);
  Settings.set('lastFMUser', null);
  delete global.lastFMSession;
  getLastFMSession();
};

var updateNowPlaying = exports.updateNowPlaying = function updateNowPlaying(track, artist, album) {
  if (Settings.get('lastFMKey')) {
    getLastFMSession().then(function (session) {
      lastfm.update('nowplaying', session, {
        track: track,
        artist: artist,
        album: album
      }).on('error', resetLastFM);
    }).catch(resetLastFM);
  }
};

var updateScrobble = exports.updateScrobble = function updateScrobble(track, artist, album, timestamp) {
  if (Settings.get('lastFMKey')) {
    getLastFMSession().then(function (session) {
      lastfm.update('scrobble', session, {
        track: track,
        artist: artist,
        album: album,
        timestamp: timestamp
      }).on('error', resetLastFM);
    }).catch(resetLastFM);
  }
};

Emitter.on('lastfm:auth', function () {
  getLastFMSession().then(function () {
    Emitter.sendToAll('lastfm:authcomplete', { result: true });
  }).catch(function () {
    Emitter.sendToAll('lastfm:authcomplete', { result: false });
  });
});

Emitter.on('change:song', function (event, details) {
  updateNowPlaying(details.title, details.artist, details.album);
});

Emitter.on('change:song:scrobble', function (event, details) {
  updateScrobble(details.title, details.artist, details.album, details.timestamp);
});