'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.resolveLyrics = undefined;

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _source_musiXmatch = require('./source_musiXmatch');

var _source_musiXmatch2 = _interopRequireDefault(_source_musiXmatch);

var _source_lyricsWikia = require('./source_lyricsWikia');

var _source_lyricsWikia2 = _interopRequireDefault(_source_lyricsWikia);

var _source_metroLyrics = require('./source_metroLyrics');

var _source_metroLyrics2 = _interopRequireDefault(_source_metroLyrics);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var attemptPromiseSequence = function attemptPromiseSequence(seq) {
  return new Promise(function (resolve, reject) {
    seq[0].then(resolve).catch(function () {
      if (seq.length <= 1) {
        reject();
      } else {
        attemptPromiseSequence(seq.slice((seq.length - 1) * -1)).then(resolve).catch(reject);
      }
    });
  });
};

// Lyrics Sources


var bracketedRegex = function bracketedRegex() {
  return (/[\(|\[].+?[\)|\]]/g
  );
};

var resolveLyrics = exports.resolveLyrics = function resolveLyrics(song) {
  var promises = [(0, _source_lyricsWikia2.default)(song.artist + ':' + song.title)];
  var bracketed = song.title.match(bracketedRegex()) || [];

  // DEV: Attempt to find lyrics from wikia
  var title = song.title;
  _lodash2.default.forEachRight(bracketed, function (bracket) {
    title = title.replace(bracket, '').trim();
    promises.push((0, _source_lyricsWikia2.default)(song.artist + ':' + title));
  });

  // DEV: Attempt to find lyrics from metro
  var lowerTitle = song.title.toLowerCase().replace(/'/g, '');
  var lowerArtist = song.artist.toLowerCase().replace(/'/g, '');
  var lowerAlbum = song.album.toLowerCase().replace(/'/g, '');
  promises.push((0, _source_metroLyrics2.default)(lowerTitle.replace(/ /g, '-') + '-lyrics-' + lowerArtist.replace(/ /g, '-')));

  var dashed = lowerAlbum.match(/- [^-]+/g) || [];
  dashed.push('');

  var album = lowerAlbum;
  _lodash2.default.forEachRight(dashed, function (dash) {
    album = album.replace(dash, '').trim();
    title = lowerTitle;

    bracketed = title.match(bracketedRegex()) || [];
    bracketed.push('');
    _lodash2.default.forEachRight(bracketed, function (bracket) {
      title = title.replace(bracket, '').trim();
      promises.push((0, _source_metroLyrics2.default)(title.replace(/ /g, '-') + '-lyrics-' + album.replace(/ /g, '-')));
    });
  });

  // DEV: Attempt to find lyrics from musixmatch
  // DEV: Last resort as the fetch is quite slow
  promises.push((0, _source_musiXmatch2.default)(song.artist + ' ' + song.title));

  return attemptPromiseSequence(promises);
};

PlaybackAPI.on('change:song', function (song) {
  resolveLyrics(song).then(function (lyrics) {
    PlaybackAPI._setPlaybackSongLyrics(lyrics);
  }).catch(function () {
    Logger.verbose('Lyrics parsing failed');
  });
});