'use strict';

var _electron = require('electron');

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _desktopSettings = require('./desktopSettings');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var appIcon = null;
var mainWindow = WindowManager.getAll('main')[0];

var audioDeviceMenu = [{
  label: 'Loading Devices...',
  enabled: false
}];

if (process.platform === 'darwin') {
  appIcon = new _electron.Tray(_path2.default.resolve(__dirname + '/../../../assets/img/macTemplate.png'));
} else {
  appIcon = new _electron.Tray(_path2.default.resolve(__dirname + '/../../../assets/img/main.png'));
}

var setContextMenu = function setContextMenu() {
  var contextMenu = _electron.Menu.buildFromTemplate([{ label: 'Show',
    click: function click() {
      mainWindow.setSkipTaskbar(false);
      mainWindow.show();
    }
  }, { type: 'separator' }, {
    label: 'Play / Pause',
    click: function click() {
      return Emitter.sendToGooglePlayMusic('playback:playPause');
    }
  }, {
    label: 'Previous Track',
    click: function click() {
      return Emitter.sendToGooglePlayMusic('playback:previousTrack');
    }
  }, {
    label: 'Next Track',
    click: function click() {
      return Emitter.sendToGooglePlayMusic('playback:nextTrack');
    }
  }, { type: 'separator' }, {
    label: 'Thumbs Up',
    click: function click() {
      return Emitter.sendToGooglePlayMusic('playback:thumbsUp');
    }
  }, {
    label: 'Thumbs Down',
    click: function click() {
      return Emitter.sendToGooglePlayMusic('playback:thumbsDown');
    }
  }, { type: 'separator' }, {
    label: 'Audio Device',
    submenu: audioDeviceMenu
  }, {
    label: 'Help',
    role: 'help',
    submenu: [{
      label: 'About',
      click: function click() {
        Emitter.sendToWindowsOfName('main', 'about');
      }
    }, {
      label: 'Issues',
      click: function click() {
        return _electron.shell.openExternal('https://github.com/MarshallOfSound/Google-Play-Music-Desktop-Player-UNOFFICIAL-/issues');
      }
    }, {
      label: 'Donate',
      click: function click() {
        return _electron.shell.openExternal('https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=23CZGASL6XMLJ');
      }
    }, {
      label: 'Learn More',
      click: function click() {
        return _electron.shell.openExternal('http://www.googleplaymusicdesktopplayer.com');
      }
    }]
  }, { label: 'Settings', click: function click() {
      (0, _desktopSettings.showDesktopSettings)();
    } }, { type: 'separator' }, { label: 'Quit', click: function click() {
      global.quiting = true;_electron.app.quit();
    } }]);
  appIcon.setContextMenu(contextMenu);
};
setContextMenu();

var wasMaximized = Settings.get('maximized', false);

// Tray icon toggle action (windows, linux)
function toggleMainWindow() {
  // the mainWindow variable will be GC'd
  // we must find the window ourselves
  var win = WindowManager.getAll('main')[0];

  if (win.isMinimized()) {
    win.setSkipTaskbar(false);
    win.show();
    if (wasMaximized) {
      win.maximize();
    }
  } else {
    wasMaximized = win.isMaximized();
    // Hide to tray, if configured
    if (Settings.get('minToTray', true)) {
      win.minimize();
      win.setSkipTaskbar(true);
    }
  }
}

appIcon.setToolTip('Google Play Music');

switch (process.platform) {
  case 'darwin':
    // <- actually means OS-X
    // No toggle action, use the context menu.
    break;
  case 'linux':
  case 'freebsd': // <- for the hipsters
  case 'sunos':
    // <- in case someone runs this in a museum
    appIcon.on('click', toggleMainWindow);
    break;
  case 'win32':
    // <- it's win32 also on 64-bit Windows
    appIcon.on('double-click', toggleMainWindow);
    break;
  default:
  // impossible case to satisfy Linters
}

// DEV: Keep the icon in the global scope or it gets garbage collected........
global.appIcon = appIcon;

_electron.app.on('before-quit', function () {
  appIcon.destroy();
  delete global.appIcon;
  appIcon = null;
});

Emitter.on('audiooutput:list', function (event, devices) {
  audioDeviceMenu = [];
  devices.forEach(function (device) {
    if (device.kind === 'audiooutput') {
      (function () {
        var label = device.label;
        if (!label) {
          switch (device.deviceId) {
            case 'default':
              label = 'System Default';
              break;
            case 'communications':
              label = 'System Default Communications';
              break;
            default:
              label = 'Unknown Device';
              break;
          }
        }
        audioDeviceMenu.push({
          label: label,
          type: 'radio',
          click: function click() {
            Emitter.sendToGooglePlayMusic('audiooutput:set', device.deviceId);
            Settings.set('audiooutput', label);
          },
          checked: label === Settings.get('audiooutput')
        });
      })();
    }
  });
  setContextMenu();
});

Emitter.sendToGooglePlayMusic('audiooutput:fetch');
Emitter.on('audiooutput:set', function () {
  return Emitter.sendToGooglePlayMusic('audiooutput:fetch');
});