'use strict';

var _ws = require('ws');

var server = void 0;
var oldTime = {};

var changeEvents = ['song', 'state', 'rating', 'lyrics', 'shuffle', 'repeat'];

changeEvents.forEach(function (channel) {
  PlaybackAPI.on('change:' + channel, function (newValue) {
    if (server && server.broadcast) {
      server.broadcast(channel, newValue);
    }
  });
});

PlaybackAPI.on('change:time', function (timeObj) {
  if (server && server.broadcast) {
    if (JSON.stringify(timeObj) !== JSON.stringify(oldTime)) {
      oldTime = timeObj;
      server.broadcast('time', timeObj);
    }
  }
});

var enableAPI = function enableAPI() {
  try {
    server = new _ws.Server({ port: 5672 });
  } catch (e) {
    // Do nothing
  }

  if (server) {
    server.broadcast = function (channel, data) {
      server.clients.forEach(function (client) {
        client.channel(channel, data);
      });
    };

    server.on('connection', function (websocket) {
      var ws = websocket;

      ws.json = function (obj) {
        ws.send(JSON.stringify(obj));
      };
      ws.channel = function (channel, obj) {
        ws.json({
          channel: channel,
          payload: obj
        });
      };

      ws.on('message', function (data) {
        try {
          var command = JSON.parse(data);
          if (command.namespace && command.method) {
            var args = command.arguments || [];
            if (!Array.isArray(args)) {
              throw Error('Bad arguments');
            }
            Emitter.sendToGooglePlayMusic('execute:gmusic', {
              namespace: command.namespace,
              method: command.method,
              args: args
            });
          } else {
            throw Error('Bad command');
          }
        } catch (err) {
          Logger.error('WebSocketAPI Error: Invalid message recieved', { err: err, data: data });
        }
      });

      ws.channel('playState', PlaybackAPI.isPlaying());
      ws.channel('shuffle', PlaybackAPI.currentShuffle());
      ws.channel('repeat', PlaybackAPI.currentRepeat());
      if (PlaybackAPI.currentSong(true)) {
        ws.channel('song', PlaybackAPI.currentSong(true));
        ws.channel('time', PlaybackAPI.currentTime());
        ws.channel('lyrics', PlaybackAPI.currentSongLyrics(true));
      }
    });
  } else {
    Emitter.sendToWindowsOfName('main', 'error', {
      title: 'Could not start Playback API',
      message: 'The playback API attempted (and failed) to start on port 5672.  Another application is probably using this port' });
  }
};

// eslint-disable-line
Emitter.on('playbackapi:toggle', function (event, state) {
  if (server) {
    server.close();
    server = null;
  }
  if (state.state) {
    enableAPI();
  }
  Settings.set('playbackAPI', state.state);
});

if (Settings.get('playbackAPI', false)) {
  enableAPI();
}