'use strict';

var _electron = require('electron');

var _mprisService = require('mpris-service');

var _mprisService2 = _interopRequireDefault(_mprisService);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function mprisService() {
  var mainWindow = WindowManager.getAll('main')[0];
  var _songInfo = {};

  var player = (0, _mprisService2.default)({
    name: 'google-play-music-desktop-player',
    identity: 'Google Play Music Desktop Player',
    canRaise: true,
    supportedInterfaces: ['player'],
    desktopEntry: 'google-play-music-desktop-player'
  });
  player.playbackStatus = 'Stopped';

  player.on('raise', function () {
    mainWindow.setSkipTaskbar(false);
    mainWindow.show();
  });

  player.on('quit', function () {
    _electron.app.quit();
  });

  player.on('play', function () {
    if (!PlaybackAPI.isPlaying()) {
      Emitter.sendToGooglePlayMusic('playback:playPause');
    }
  });

  player.on('playpause', function () {
    Emitter.sendToGooglePlayMusic('playback:playPause');
  });

  player.on('next', function () {
    Emitter.sendToGooglePlayMusic('playback:nextTrack');
  });

  player.on('previous', function () {
    Emitter.sendToGooglePlayMusic('playback:previousTrack');
  });

  player.on('stop', function () {
    Emitter.sendToGooglePlayMusic('playback:stop');
    player.playbackStatus = 'Stopped';
  });

  PlaybackAPI.on('change:song', function (newSong) {
    player.metadata = _songInfo = {
      'mpris:artUrl': newSong.albumArt.replace('=s90', '=s300'),
      'xesam:asText': newSong.lyrics || '',
      'xesam:title': newSong.title,
      'xesam:album': newSong.album,
      'xesam:artist': [newSong.artist]
    };
  });

  PlaybackAPI.on('change:time', function (time) {
    var newPosition = time.current * 1e3;
    var newTotal = time.total * 1e3;
    var delta = newPosition - player.position;

    if (_songInfo && _songInfo['mpris:length'] !== newTotal) {
      player.metadata = _lodash2.default.extend(_songInfo, {
        'mpris:length': newTotal
      });
    }

    if (Math.abs(delta) > 2e6) {
      player.seeked(delta);
    } else {
      player.position = newPosition;
    }
  });

  PlaybackAPI.on('change:state', function (playbackState) {
    // DEV: We skip stopped here because PlaybackAPI only shuttles true/false from GPM
    player.playbackStatus = playbackState ? 'Playing' : 'Paused';
  });
}

mprisService();