'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _jsonCreator = require('./_jsonCreator');

var _jsonCreator2 = _interopRequireDefault(_jsonCreator);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var PlaybackAPI = function () {
  function PlaybackAPI() {
    _classCallCheck(this, PlaybackAPI);

    this.PATH = (0, _jsonCreator2.default)('playback');
    this.reset();
    this._save();
    if (Settings.get('enableJSONApi', true)) {
      // DEV: Handle windows users running as admin...
      _fs2.default.chmodSync(this.PATH, '777');
    }

    this._ev = {};

    this._hook();
  }

  _createClass(PlaybackAPI, [{
    key: '_hook',
    value: function _hook() {
      var _this = this;

      Emitter.on('change:song', function (event, details) {
        _this._setPlaybackSong(details.title, details.artist, details.album, details.art);
      });

      Emitter.on('playback:isPlaying', this._setPlaying.bind(this, true));
      Emitter.on('playback:isPaused', this._setPlaying.bind(this, false));
      Emitter.on('playback:isStopped', this._setPlaying.bind(this, false));

      Emitter.on('change:playback-time', function (event, timeObj) {
        _this._setTime(timeObj.current, timeObj.total);
      });
      // we throttle this function because of a bug in gmusic.js
      // ratings are received multiple times here in a couple of ms
      // to avoid writing the file 5+ times we throttle it to 500ms max
      Emitter.on('change:rating', _lodash2.default.throttle(function (event, details) {
        _this._setRating(details);
      }, 500));

      Emitter.on('change:shuffle', _lodash2.default.throttle(function (event, mode) {
        _this._setShuffle(mode);
      }), 20);
      Emitter.on('change:repeat', _lodash2.default.throttle(function (event, mode) {
        _this._setRepeat(mode);
      }), 20);
    }
  }, {
    key: 'reset',
    value: function reset() {
      this.data = {
        playing: false,
        song: {
          title: null,
          artist: null,
          album: null,
          albumArt: null
        },
        rating: {
          liked: false,
          disliked: false
        },
        time: {
          current: 0,
          total: 0
        },
        songLyrics: null,
        shuffle: null,
        repeat: null
      };
      this._save();
    }
  }, {
    key: '_save',
    value: function _save() {
      if (Settings.get('enableJSONApi', true)) {
        _fs2.default.writeFileSync(this.PATH, JSON.stringify(this.data, null, 4));
      }
    }
  }, {
    key: '_setPlaying',
    value: function _setPlaying(isPlaying) {
      this.data.playing = isPlaying;
      this._fire('change:state', isPlaying);
      this._save();
    }
  }, {
    key: '_setPlaybackSong',
    value: function _setPlaybackSong(title, artist, album, albumArt) {
      this.data.song = {
        title: title,
        artist: artist,
        album: album,
        albumArt: albumArt
      };
      this._resetRating();
      this.data.songLyrics = null;
      this._fire('change:song', this.data.song);
      this._fire('change:lyrics', this.data.songLyrics);
      this._save();
    }
  }, {
    key: '_setRating',
    value: function _setRating(rating) {
      this.data.rating.liked = rating === '5';
      this.data.rating.disliked = rating === '1';
      this._fire('change:rating', this.data.rating);
      this._save();
    }
  }, {
    key: '_resetRating',
    value: function _resetRating() {
      this.data.rating.liked = false;
      this.data.rating.disliked = false;
    }
  }, {
    key: '_setPlaybackSongLyrics',
    value: function _setPlaybackSongLyrics(lyricString) {
      this.data.songLyrics = lyricString;
      this._fire('change:lyrics', this.data.songLyrics);
      this._save();
    }
  }, {
    key: '_setShuffle',
    value: function _setShuffle(mode) {
      this.data.shuffle = mode;
      this._fire('change:shuffle', this.data.shuffle);
      this._save();
    }
  }, {
    key: '_setRepeat',
    value: function _setRepeat(mode) {
      this.data.repeat = mode;
      this._fire('change:repeat', this.data.repeat);
      this._save();
    }
  }, {
    key: '_setTime',
    value: function _setTime(current, total) {
      var totalTime = total || this.data.time.total;
      this.data.time = {
        current: current,
        total: totalTime
      };
      this._fire('change:time', this.data.time);
      this._save();
    }
  }, {
    key: 'isPlaying',
    value: function isPlaying() {
      return this.data.playing;
    }
  }, {
    key: 'currentRepeat',
    value: function currentRepeat() {
      return this.data.repeat;
    }
  }, {
    key: 'currentShuffle',
    value: function currentShuffle() {
      return this.data.shuffle;
    }
  }, {
    key: 'currentSong',
    value: function currentSong(force) {
      return this.data.playing || force ? this.data.song : null;
    }
  }, {
    key: 'currentSongLyrics',
    value: function currentSongLyrics(force) {
      return this.data.playing || force ? this.data.songLyrics : null;
    }
  }, {
    key: 'currentTime',
    value: function currentTime() {
      return this.data.time;
    }
  }, {
    key: 'on',
    value: function on(what, fn) {
      this._ev[what] = this._ev[what] || [];
      this._ev[what].push(fn);
    }
  }, {
    key: '_fire',
    value: function _fire(what, arg) {
      this._ev[what] = this._ev[what] || [];
      this._ev[what].forEach(function (fn) {
        fn(arg);
      });
    }
  }]);

  return PlaybackAPI;
}();

exports.default = PlaybackAPI;